/// <reference types="react" />
import React$1, { MouseEvent, ChangeEventHandler } from 'react';

type AvatarSizes = "small" | "medium" | "large";
interface AvatarProps {
    src: string;
    size?: AvatarSizes;
    customSize?: React.CSSProperties["width"];
    alt?: HTMLImageElement["alt"];
    asText?: boolean;
    rounded?: boolean;
    customClass?: string;
    customStyles?: React.CSSProperties;
}

declare const Avatar: ({ alt, size, src, asText, customClass, customStyles, customSize, }: AvatarProps) => JSX.Element;

type BadgeVariants = "dashed" | "ghost" | "outlined";
type BadgeThemes = "primary" | "secondary" | "success" | "danger" | "warning" | "default";
type BadgeSizes = "small" | "medium" | "large";
interface BadgeProps {
    variant?: BadgeVariants;
    theme?: BadgeThemes;
    children?: React$1.ReactNode | string;
    size?: BadgeSizes;
    customClass?: string;
    customStyles?: React$1.CSSProperties;
}

declare const Badge: ({ variant, theme, children, size, customStyles, customClass, }: BadgeProps) => JSX.Element;

type BoxVariants = "primary" | "secondary" | "success" | "danger" | "warning" | "default";
type BoxTextColor = "dark" | "light" | "darker" | "lighter";
interface BoxProps {
    bgColor?: BoxVariants;
    textColor?: BoxTextColor;
    centered?: boolean;
    width?: React.CSSProperties["width"];
    height?: React.CSSProperties["height"];
    padding?: React.CSSProperties["margin"];
    margin?: React.CSSProperties["margin"];
    borderRadius?: React.CSSProperties["borderRadius"];
    customClass?: string;
    customStyles?: React.CSSProperties;
    children?: React.ReactNode;
    gridSpan?: {
        row?: number;
        col?: number;
    };
}

declare const Box: ({ width, children, padding, margin, height, bgColor, borderRadius, customClass, customStyles, centered, textColor, gridSpan, }: BoxProps) => JSX.Element;

type ButtonThemes = "primary" | "secondary" | "success" | "danger" | "warning" | "default";
type ButtonVariants = "filled" | "outlined" | "ghost";
type ButtonTypes = "submit" | "reset" | "button";
type ButtonSizes = "small" | "medium" | "large";
interface ButtonState {
    disabled?: boolean;
}
interface ButtonProps {
    theme?: ButtonThemes;
    variant?: ButtonVariants;
    type?: ButtonTypes;
    size?: ButtonSizes;
    onClick?: (event?: MouseEvent<HTMLButtonElement>) => void;
    state?: ButtonState;
    children?: React.ReactNode;
    customClass?: string;
    customStyles?: React.CSSProperties;
}

declare const Button: ({ theme, size, variant, type, onClick, state, children, customClass, customStyles, }: ButtonProps) => JSX.Element;

type CheckboxState = {
    disabled?: boolean;
};
type CheckboxSizes = "small" | "medium" | "large";
interface CheckboxProps {
    fieldKey: string;
    label?: string;
    size?: CheckboxSizes;
    defaultChecked?: boolean;
    state?: CheckboxState;
    width?: React.CSSProperties["width"];
    customClass?: string;
    customStyles?: React.CSSProperties;
    customInputClass?: string;
    customInputStyles?: React.CSSProperties;
    customLabelClass?: string;
    customLabelStyles?: React.CSSProperties;
    onChange?: (event: React.ChangeEvent<HTMLInputElement>) => void;
}

declare const Checkbox: ({ fieldKey, label, size, defaultChecked, onChange, state, width, customClass, customStyles, customInputStyles, customInputClass, customLabelClass, customLabelStyles, }: CheckboxProps) => JSX.Element;

interface GridProps {
    cols?: React$1.CSSProperties["gridTemplateColumns"] | number;
    rows?: React$1.CSSProperties["gridTemplateRows"] | number;
    gap?: {
        row?: React$1.CSSProperties["rowGap"];
        col?: React$1.CSSProperties["columnGap"];
    };
    width?: React$1.CSSProperties["width"];
    padding?: React$1.CSSProperties["padding"];
    children?: React$1.ReactNode;
    customStyles?: React$1.CSSProperties;
    customClass?: string;
}

declare const Grid: ({ rows, cols, gap, width, padding, children, customClass, customStyles, }: GridProps) => JSX.Element;

type InputTypes = "text" | "password" | "email";
type InputSizes = "small" | "medium" | "large";
type InputVariant = "outlined" | "filled";
type InputState = {
    disabled?: boolean;
};
interface InputProps {
    fieldKey?: string;
    type?: InputTypes;
    size?: InputSizes;
    variant?: InputVariant;
    width?: React$1.CSSProperties["width"];
    placeholder?: string;
    onChange?: ChangeEventHandler<HTMLInputElement>;
    customStyles?: React$1.CSSProperties;
    customClass?: string;
    state?: InputState;
}

declare const Input: ({ fieldKey, type, variant, placeholder, onChange, size, width, customClass, customStyles, state, }: InputProps) => JSX.Element;

type SelectOption = {
    value: string;
    label: string;
    state?: {
        disabled?: boolean;
        selected?: boolean;
    };
};
type SelectSizes = "small" | "medium" | "large";
type SelectVariant = "filled" | "outlined";
type SelectState = {
    disabled?: boolean;
};
interface SelectProps {
    fieldKey?: string;
    size?: SelectSizes;
    placeholder?: string;
    width?: React$1.CSSProperties["width"];
    variant?: SelectVariant;
    onChange?: (value: string[]) => void;
    state?: SelectState;
    defaultValue?: string[];
    multiple?: boolean;
    options: SelectOption[];
    clickOptionHide?: boolean;
    clickOutsideHide?: boolean;
    valueSeparator?: string;
    selectCustomClass?: string;
    selectCustomStyles?: React$1.CSSProperties;
    optionCustomClass?: string;
    optionCustomStyles?: React$1.CSSProperties;
    dropdownCustomClass?: string;
    dropdownCustomStyles?: React$1.CSSProperties;
}

declare const Select: ({ fieldKey, onChange, placeholder, size, state, variant, width, defaultValue, multiple, options, clickOptionHide, clickOutsideHide, valueSeparator, optionCustomStyles, optionCustomClass, selectCustomClass, selectCustomStyles, dropdownCustomClass, dropdownCustomStyles, }: SelectProps) => JSX.Element;

type TextAreaVariants = "outlined" | "filled";
type TextAreaSizes = "small" | "medium" | "large";
type TextAreaState = {
    disabled?: boolean;
};
interface TextAreaProps {
    fieldKey?: string;
    variant?: TextAreaVariants;
    size?: TextAreaSizes;
    minRows?: number;
    rows?: number;
    defaultValue?: string;
    onChange?: (e: React.ChangeEvent<HTMLTextAreaElement>) => void;
    state?: TextAreaState;
    placeholder?: string;
    resize?: boolean;
    width?: React.CSSProperties["width"];
    customClass?: string;
    customStyles?: React.CSSProperties;
    textAreaProps?: React.TextareaHTMLAttributes<HTMLTextAreaElement>;
}

declare const TextArea: ({ fieldKey, variant, width, size, resize, rows, minRows, state, customClass, customStyles, placeholder, onChange, defaultValue, textAreaProps, }: TextAreaProps) => JSX.Element;

type TooltipDirections = "top" | "bottom" | "left" | "right";
type TooltipThemes = "primary" | "secondary" | "success" | "danger" | "warning" | "default";
interface TooltipProps {
    direction?: TooltipDirections;
    theme?: TooltipThemes;
    customClass?: string;
    customStyles?: React.CSSProperties;
    title: string;
    children?: React.ReactNode;
}

declare const Tooltip: ({ children, title, direction, customClass, customStyles, theme, }: TooltipProps) => JSX.Element;

type TopographyTypes = "h1" | "h2" | "h3" | "h4" | "h5" | "h6" | "subtitle-1" | "subtitle-2" | "body-1" | "body-2" | "caption" | "button" | "overline";
interface TopographyProps {
    children?: React$1.ReactNode;
    type: TopographyTypes;
    customClass?: string;
    customStyles?: React$1.CSSProperties;
}

declare const Topography: ({ type, children, customClass, customStyles }: TopographyProps) => React$1.ReactElement<any, string | React$1.JSXElementConstructor<any>>;

type LeSizes = "small" | "medium" | "large";
type LeVariants = "primary" | "secondary" | "success" | "danger" | "warning" | "default";

declare namespace index_d {
  export {
  };
}

type LeBreakpoints = "sm" | "md" | "lg" | "xl";
type LeBreakpointType = {
    breakpoint: LeBreakpoints;
};
/**
 * useBreakpoint hook
 *
 * A one-liner hook to get the current breakpoint based on the window.innerWidth
 * always updated when the window is resized.
 *
 *
 * @returns {LeBreakpointType} `sm | md | lg | xl`
 */
declare function useBreakpoint(): LeBreakpointType;

export { Avatar, AvatarProps, AvatarSizes, Badge, BadgeProps, BadgeSizes, BadgeThemes, BadgeVariants, Box, BoxProps, BoxTextColor, BoxVariants, Button, ButtonProps, ButtonSizes, ButtonState, ButtonThemes, ButtonTypes, ButtonVariants, Checkbox, CheckboxProps, CheckboxSizes, CheckboxState, Grid, GridProps, Input, InputProps, InputSizes, InputState, InputTypes, InputVariant, LeBreakpointType, LeBreakpoints, index_d as LeCSS, LeSizes, LeVariants, Select, SelectOption, SelectProps, SelectSizes, SelectState, SelectVariant, TextArea, TextAreaProps, TextAreaSizes, TextAreaState, TextAreaVariants, Tooltip, TooltipDirections, TooltipProps, Topography, TopographyProps, TopographyTypes, useBreakpoint };
